TinyXml: Member List

# TiXmlAttribute Member List

This is the complete list of members for TiXmlAttribute, including all inherited members.

Column() const | TiXmlBase | `[inline]`
DoubleValue() const | TiXmlAttribute |
EncodeString(const TIXML_STRING &str, TIXML_STRING *out) | TiXmlBase | `[static]`
GetUserData() | TiXmlBase | `[inline]`
GetUserData() const | TiXmlBase | `[inline]`
IntValue() const | TiXmlAttribute |
IsWhiteSpaceCondensed() | TiXmlBase | `[inline, static]`
Name() const | TiXmlAttribute | `[inline]`
Next() const | TiXmlAttribute |
Previous() const | TiXmlAttribute |
Print(FILE *cfile, int depth) const | TiXmlAttribute | `[inline, virtual]`
QueryDoubleValue(double *_value) const | TiXmlAttribute |
QueryIntValue(int *_value) const | TiXmlAttribute |
Row() const | TiXmlBase | `[inline]`
SetCondenseWhiteSpace(bool condense) | TiXmlBase | `[inline, static]`
SetDoubleValue(double _value) | TiXmlAttribute |
SetIntValue(int _value) | TiXmlAttribute |
SetName(const char *_name) | TiXmlAttribute | `[inline]`
SetName(const std::string &_name) | TiXmlAttribute | `[inline]`
SetUserData(void *user) | TiXmlBase | `[inline]`
SetValue(const char *_value) | TiXmlAttribute | `[inline]`
SetValue(const std::string &_value) | TiXmlAttribute | `[inline]`
TiXmlAttribute() | TiXmlAttribute | `[inline]`
TiXmlAttribute(const std::string &_name, const std::string &_value) | TiXmlAttribute | `[inline]`
TiXmlAttribute(const char *_name, const char *_value) | TiXmlAttribute | `[inline]`
userData | TiXmlBase | `[protected]`
Value() const | TiXmlAttribute | `[inline]`
ValueStr() const | TiXmlAttribute | `[inline]`